<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright (C) 2002 Hewlett-Packard Development Group, L.P. -->
<!DOCTYPE xsl:stylesheet [
<!-- common entities must be in the same relative location for all projects -->
<!ENTITY % common_ja SYSTEM "../dtd.ja/common.dtd">
%common_ja;
<!ENTITY % vclog_ja SYSTEM "../dtd.ja/vclog.dtd">
%vclog_ja;
<!-- vclogtxt entities -->
<!ENTITY showHideDetails       "詳細の表示/非表示">
]>
<!-- end of localization preface -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
   <xsl:output indent="yes" method="html" encoding="UTF-8"/>
   <!-- 'true' displays the task id data column -->
   <xsl:param name="showTaskIds"/>
   <!--
   ////////////////////////////////////////////////////////////////////////
   // Create table view of the log
   ////////////////////////////////////////////////////////////////////////
   -->
   <xsl:template match="/&log_element;">
      <!-- language code -->
      <xsl:param name="lang">&default_lang_code;</xsl:param>
      <html>
         <head>
            <style>
              div.logtable {width:100%;height: 90%;border:solid black 1px;}
              table {font-family: verdana, arial, helvetica;border-collapse:collapse;border:solid black 2px;}
              th {font-size:11pt;font-weight:bold;text-align:left;border:solid black 2px;}
              tr {font-size:10pt;font-weight:normal;}
              td {text-align:left;border-style:solid;border-width:1px 1px 1px 1px;}
              td.details {border-width:0px 1px 0px 1px;}
              p.details {font-family:georgia,courier;font-weight:normal;font-size:9pt;margin-left:5}
              table.footer {border-width:0px;}
              td.footer {border-width:0px;}
            </style>
            <title>&agent_name;&#032;:&#032;<xsl:value-of select="created/onMachine/@name"/></title>
            <script language="javascript">
               function localTime(dt) {
                  var y, m, d, h, n, s;
                  y = dt.substr(0, 4); m = dt.substr(5, 2); d = dt.substr(8, 2);
                  h = dt.substr(11, 2); n = dt.substr(14, 2); s = dt.substr(17, 2);
                  var dtLocal = new Date(Date.UTC(y, m, d, h, n, s));
                  return dtLocal.toLocaleString();
               }

               function showhide(id) {
                 if( (document.getElementById(id).style.display == "none")) {
                   document.getElementById(id).style.display = "block";
                 }
                 else {
                   document.getElementById(id).style.display = "none";
                 }
               }
            </script>
         </head>
         <body>
            <!--div class="logtable"-->
               <!-- output the log entries table header -->
               <table width="100%">
               <!-- here is the table header -->
               <thead>
                  <tr>
                     <th>&severity;</th>
                     <xsl:if test="$showTaskIds='true'">
                        <th>&task_id;</th>
                     </xsl:if>
                     <th>&date_time;</th>
                     <th>&message;</th>
                  </tr>
               </thead>
               <tbody>
                  <!-- here are the table rows -->
                  <xsl:apply-templates select="entry">
                     <xsl:with-param name="showTaskIds" select="$showTaskIds"/>
                     <xsl:with-param name="lang" select="$lang"/>
                     <xsl:sort select="@timestamp" order="descending"/>
                  </xsl:apply-templates>
               </tbody>
            </table>
         <!--/div-->
         <br/>
         <!--div-->
            <table class="footer">
               <tr>
                  <td class="footer">
                    <b>&totalEntriesLabel;</b>
                     <xsl:value-of select="total_entries"/>
                  </td>
               </tr>
               <tr>
                  <td class="footer">
                     <b>&logCreatedLabel;</b>
                     <script language="JavaScript">document.write(localTime("<xsl:value-of select="created/when/@utcDateTime"/>"));</script>
                  </td>
               </tr>
            </table>
         <!--/div-->
      </body>
      </html>
   </xsl:template>

   <xsl:template match="entry">
      <!-- set false to remove this column's data, true to add it -->
      <xsl:param name="showTaskIds"/>
      <xsl:param name="lang"/>
      <xsl:variable name="detailsId">details<xsl:number value="position()"/></xsl:variable>
      <tr>
         <td>
            <xsl:choose>
               <xsl:when test="severity = 100">&txt_info;</xsl:when>
               <xsl:when test="severity = 1">&txt_normal;</xsl:when>
               <xsl:when test="severity = 3">&txt_minor;</xsl:when>
               <xsl:when test="severity = 4">&txt_major;</xsl:when>
               <xsl:otherwise>&txt_unknown;</xsl:otherwise>
            </xsl:choose>
         </td>
         <xsl:if test="$showTaskIds='true'">
            <td><xsl:value-of select="taskid"/></td>
         </xsl:if>
         <td>
            <script language="JavaScript">document.write(localTime("<xsl:value-of select="@timestamp"/>"));</script>
         </td>
         <td>
            <xsl:choose>
               <xsl:when test="xlates/xlate[@lang=$lang]">
                  <xsl:value-of select="xlates/xlate[@lang=$lang]"/>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:value-of select="xlates/xlate[@lang='en']"/>
               </xsl:otherwise>
            </xsl:choose>
            <xsl:if test="vcrm_href">&#032;[<xsl:value-of select="vcrm_href/@txt"/>]</xsl:if>
            <xsl:if test="data">&#032;[<a href="#"><xsl:attribute name="onclick">showhide('<xsl:value-of select="$detailsId"/>')</xsl:attribute>&showHideDetails;</a>]
               <p class="details" style="display:none;">
                  <xsl:attribute name="id"><xsl:value-of select="$detailsId"/></xsl:attribute>
                  <xsl:value-of select="data" disable-output-escaping="yes"/>
               </p>
            </xsl:if>

         </td>
      </tr>
   </xsl:template>
</xsl:stylesheet>
